@@ -7,7 +7,13 @@ from pymatgen.core.structure import Structure
 from matminer.datasets import load_dataset
 from emmet.core.thermo import ThermoType
 
-from pymatgen.analysis.alloys.core import AlloyPair, InvalidAlloy, KNOWN_ANON_FORMULAS, AlloyMember, AlloySystem
+from pymatgen.analysis.alloys.core import (
+    AlloyPair,
+    InvalidAlloy,
+    KNOWN_ANON_FORMULAS,
+    AlloyMember,
+    AlloySystem,
+)
 
 # rough sort of ANON_FORMULAS by "complexity"
 ANON_FORMULAS = sorted(KNOWN_ANON_FORMULAS, key=lambda af: len(af))
@@ -26,10 +32,16 @@ class AlloyPairBuilder(Builder):
     It does not look for members of an AlloyPair.
     """
 
-    def __init__(self, materials, thermo, electronic_structure,
-                 provenance, oxi_states, alloy_pairs,
-                 thermo_type: Union[ThermoType, str] = ThermoType.GGA_GGA_U_R2SCAN):
-
+    def __init__(
+        self,
+        materials,
+        thermo,
+        electronic_structure,
+        provenance,
+        oxi_states,
+        alloy_pairs,
+        thermo_type: Union[ThermoType, str] = ThermoType.GGA_GGA_U_R2SCAN,
+    ):
         self.materials = materials
         self.thermo = thermo
         self.electronic_structure = electronic_structure
@@ -40,7 +52,9 @@ class AlloyPairBuilder(Builder):
         t_type = thermo_type if isinstance(thermo_type, str) else thermo_type.value
         valid_types = {*map(str, ThermoType.__members__.values())}
         if invalid_types := {t_type} - valid_types:
-            raise ValueError(f"Invalid thermo type(s) passed: {invalid_types}, valid types are: {valid_types}")
+            raise ValueError(
+                f"Invalid thermo type(s) passed: {invalid_types}, valid types are: {valid_types}"
+            )
 
         self.thermo_type = t_type
 
@@ -51,7 +65,6 @@ class AlloyPairBuilder(Builder):
         )
 
     def ensure_indexes(self):
-
         self.alloy_pairs.ensure_index("pair_id")
         self.alloy_pairs.ensure_index("_search.id")
         self.alloy_pairs.ensure_index("_search.formula")
@@ -59,57 +72,74 @@ class AlloyPairBuilder(Builder):
         self.alloy_pairs.ensure_index("alloy_pair.chemsys")
 
     def get_items(self):
-
         self.ensure_indexes()
 
         for idx, af in enumerate(ANON_FORMULAS):
-
             # if af != "AB":
             #     continue
 
-            docs = self.materials.query(
+            thermo_docs = self.thermo.query(
                 criteria={
                     "formula_anonymous": af,
                     "deprecated": False,
+                    "thermo_type": self.thermo_type,
+                },
+                properties=[
+                    "material_id",
+                    "energy_above_hull",
+                    "formation_energy_per_atom",
+                ],
+            )
+
+            thermo_docs = {d["material_id"]: d for d in thermo_docs}
+
+            mpids = list(thermo_docs.keys())
+
+            docs = self.materials.query(
+                criteria={
+                    "material_id": {"$in": mpids},
+                    "deprecated": False,
                 },  # , "material_id": {"$in": ["mp-804", "mp-661"]}},
                 properties=["structure", "material_id", "symmetry.number"],
             )
             docs = {d["material_id"]: d for d in docs}
 
-            mpids = list(docs.keys())
-
-            thermo_docs = self.thermo.query(
-                {"material_id": {"$in": mpids}, "thermo_type": self.thermo_type},
-                properties=["material_id", "energy_above_hull", "formation_energy_per_atom"],
-            )
-            thermo_docs = {d["material_id"]: d for d in thermo_docs}
-
             electronic_structure_docs = self.electronic_structure.query(
-                {"material_id": {"$in": mpids}}, properties=["material_id", "band_gap", "is_gap_direct"]
+                {"material_id": {"$in": mpids}},
+                properties=["material_id", "band_gap", "is_gap_direct"],
             )
-            electronic_structure_docs = {d["material_id"]: d for d in electronic_structure_docs}
+            electronic_structure_docs = {
+                d["material_id"]: d for d in electronic_structure_docs
+            }
 
             provenance_docs = self.provenance.query(
-                {"material_id": {"$in": mpids}}, properties=["material_id", "theoretical", "database_IDs"]
+                {"material_id": {"$in": mpids}},
+                properties=["material_id", "theoretical", "database_IDs"],
             )
             provenance_docs = {d["material_id"]: d for d in provenance_docs}
 
             oxi_states_docs = self.oxi_states.query(
-                {"material_id": {"$in": mpids}, "state": "successful"}, properties=["material_id", "structure"]
+                {"material_id": {"$in": mpids}, "state": "successful"},
+                properties=["material_id", "structure"],
             )
             oxi_states_docs = {d["material_id"]: d for d in oxi_states_docs}
 
-            for material_id, d in docs.items():
+            for material_id in mpids:
+                d = docs[material_id]
 
                 d["structure"] = Structure.from_dict(d["structure"])
 
                 if material_id in oxi_states_docs:
-                    d["structure_oxi"] = Structure.from_dict(oxi_states_docs[material_id]["structure"])
+                    d["structure_oxi"] = Structure.from_dict(
+                        oxi_states_docs[material_id]["structure"]
+                    )
                 else:
                     d["structure_oxi"] = d["structure"]
 
                 # calculate loose space group
-                d["spacegroup_loose"] = d["structure"].get_space_group_info(LOOSE_SPACEGROUP_SYMPREC)[1]
+                d["spacegroup_loose"] = d["structure"].get_space_group_info(
+                    LOOSE_SPACEGROUP_SYMPREC
+                )[1]
 
                 d["properties"] = {}
                 # patch in BoltzTraP data if present
@@ -120,7 +150,9 @@ class AlloyPairBuilder(Builder):
 
                 if material_id in electronic_structure_docs:
                     for key in ("band_gap", "is_gap_direct"):
-                        d["properties"][key] = electronic_structure_docs[material_id][key]
+                        d["properties"][key] = electronic_structure_docs[material_id][
+                            key
+                        ]
 
                 for key in ("energy_above_hull", "formation_energy_per_atom"):
                     d["properties"][key] = thermo_docs[material_id][key]
@@ -129,30 +161,46 @@ class AlloyPairBuilder(Builder):
                     for key in ("theoretical",):
                         d["properties"][key] = provenance_docs[material_id][key]
 
-            print(f"Starting {af} with {len(docs)} materials, anonymous formula {idx} of {len(ANON_FORMULAS)}")
+            print(
+                f"Starting {af} with {len(docs)} materials, anonymous formula {idx} of {len(ANON_FORMULAS)}"
+            )
 
             yield docs
 
     def process_item(self, item):
-
         pairs = []
         for mpids in tqdm(list(combinations(item.keys(), 2))):
-            if (item[mpids[0]]["symmetry"]["number"] == item[mpids[1]]["symmetry"]["number"]) or (
+            if (
+                item[mpids[0]]["symmetry"]["number"]
+                == item[mpids[1]]["symmetry"]["number"]
+            ) or (
                 item[mpids[0]]["spacegroup_loose"] == item[mpids[1]]["spacegroup_loose"]
             ):
                 # optionally, could restrict based on band gap too (e.g. at least one end-point semiconducting)
                 # if (item[mpids[0]]["band_gap"] > 0) or (item[mpids[1]]["band_gap"] > 0):
                 try:
                     pair = AlloyPair.from_structures(
-                        structures=[item[mpids[0]]["structure"], item[mpids[1]]["structure"]],
+                        structures=[
+                            item[mpids[0]]["structure"],
+                            item[mpids[1]]["structure"],
+                        ],
                         structures_with_oxidation_states=[
                             item[mpids[0]]["structure_oxi"],
                             item[mpids[1]]["structure_oxi"],
                         ],
                         ids=[mpids[0], mpids[1]],
-                        properties=[item[mpids[0]]["properties"], item[mpids[1]]["properties"]],
+                        properties=[
+                            item[mpids[0]]["properties"],
+                            item[mpids[1]]["properties"],
+                        ],
+                    )
+                    pairs.append(
+                        {
+                            "alloy_pair": pair.as_dict(),
+                            "_search": pair.search_dict(),
+                            "pair_id": pair.pair_id,
+                        }
                     )
-                    pairs.append({"alloy_pair": pair.as_dict(), "_search": pair.search_dict(), "pair_id": pair.pair_id})
                 except InvalidAlloy:
                     pass
                 except Exception as exc:
@@ -164,7 +212,6 @@ class AlloyPairBuilder(Builder):
         return pairs
 
     def update_targets(self, items):
-
         docs = list(chain.from_iterable(items))
         if docs:
             self.alloy_pairs.update(docs)
@@ -177,16 +224,16 @@ class AlloyPairMemberBuilder(Builder):
     """
 
     def __init__(self, alloy_pairs, materials, snls, alloy_pair_members):
-
         self.alloy_pairs = alloy_pairs
         self.materials = materials
         self.snls = snls
         self.alloy_pair_members = alloy_pair_members
 
-        super().__init__(sources=[alloy_pairs, materials, snls], targets=[alloy_pair_members])
+        super().__init__(
+            sources=[alloy_pairs, materials, snls], targets=[alloy_pair_members]
+        )
 
     def ensure_indexes(self):
-
         self.alloy_pairs.ensure_index("pair_id")
         self.alloy_pairs.ensure_index("_search.id")
         self.alloy_pairs.ensure_index("_search.formula")
@@ -195,9 +242,10 @@ class AlloyPairMemberBuilder(Builder):
         self.alloy_pairs.ensure_index("alloy_pair.anonymous_formula")
 
     def get_items(self):
-
         all_alloy_chemsys = set(self.alloy_pairs.distinct("alloy_pair.chemsys"))
-        all_known_chemsys = set(self.materials.distinct("chemsys")) | set(self.snls.distinct("chemsys"))
+        all_known_chemsys = set(self.materials.distinct("chemsys")) | set(
+            self.snls.distinct("chemsys")
+        )
         possible_chemsys = all_known_chemsys.intersection(all_alloy_chemsys)
 
         print(
@@ -206,14 +254,16 @@ class AlloyPairMemberBuilder(Builder):
         )
 
         for idx, chemsys in enumerate(possible_chemsys):
-
             pairs = self.alloy_pairs.query(criteria={"alloy_pair.chemsys": chemsys})
             pairs = [AlloyPair.from_dict(d["alloy_pair"]) for d in pairs]
 
             mp_docs = self.materials.query(
-                criteria={"chemsys": chemsys, "deprecated": False}, properties=["structure", "material_id"]
+                criteria={"chemsys": chemsys, "deprecated": False},
+                properties=["structure", "material_id"],
             )
-            mp_structures = {d["material_id"]: Structure.from_dict(d["structure"]) for d in mp_docs}
+            mp_structures = {
+                d["material_id"]: Structure.from_dict(d["structure"]) for d in mp_docs
+            }
 
             snl_docs = self.snls.query({"chemsys": chemsys})
             snl_structures = {d["snl_id"]: Structure.from_dict(d) for d in snl_docs}
@@ -225,7 +275,6 @@ class AlloyPairMemberBuilder(Builder):
                 yield (pairs, structures)
 
     def process_item(self, item: Tuple[List[AlloyPair], Dict[str, Structure]]):
-
         pairs, structures = item
 
         all_pair_members = []
@@ -251,7 +300,6 @@ class AlloyPairMemberBuilder(Builder):
         return all_pair_members
 
     def update_targets(self, items):
-
         docs = list(chain.from_iterable(items))
         if docs:
             self.alloy_pair_members.update(docs)
@@ -265,40 +313,45 @@ class AlloySystemBuilder(Builder):
     It also builds AlloySystem.
     """
 
-    def __init__(self, alloy_pairs, alloy_pair_members, alloy_pairs_merged, alloy_systems):
-
+    def __init__(
+        self, alloy_pairs, alloy_pair_members, alloy_pairs_merged, alloy_systems
+    ):
         self.alloy_pairs = alloy_pairs
         self.alloy_pair_members = alloy_pair_members
         self.alloy_pairs_merged = alloy_pairs_merged
         self.alloy_systems = alloy_systems
 
         super().__init__(
-            sources=[alloy_pairs, alloy_pair_members], targets=[alloy_pairs_merged, alloy_systems], chunk_size=8
+            sources=[alloy_pairs, alloy_pair_members],
+            targets=[alloy_pairs_merged, alloy_systems],
+            chunk_size=8,
         )
 
     def get_items(self):
-
         for idx, af in enumerate(ANON_FORMULAS):
-
             # comment out to only calculate a single anonymous formula for debugging
             # if af != "AB":
             #     continue
 
             docs = list(self.alloy_pairs.query({"alloy_pair.anonymous_formula": af}))
             pair_ids = [d["pair_id"] for d in docs]
-            members = {d["pair_id"]: d for d in self.alloy_pair_members.query({"pair_id": {"$in": pair_ids}})}
+            members = {
+                d["pair_id"]: d
+                for d in self.alloy_pair_members.query({"pair_id": {"$in": pair_ids}})
+            }
 
             if docs:
                 yield docs, members
 
     def process_item(self, item):
-
         pair_docs, members = item
 
         for doc in pair_docs:
             if doc["pair_id"] in members:
                 doc["alloy_pair"]["members"] = members[doc["pair_id"]]["members"]
-                doc["_search"]["member_ids"] = [m["id_"] for m in members[doc["pair_id"]]["members"]]
+                doc["_search"]["member_ids"] = [
+                    m["id_"] for m in members[doc["pair_id"]]["members"]
+                ]
             else:
                 doc["alloy_pair"]["members"] = []
                 doc["_search"]["member_ids"] = []
@@ -322,7 +375,6 @@ class AlloySystemBuilder(Builder):
         return pair_docs, system_docs
 
     def update_targets(self, items):
-
         pair_docs, system_docs = [p for p, s in items], [s for p, s in items]
 
         pair_docs = list(chain.from_iterable(pair_docs))
