@@ -1,7 +1,10 @@
 from collections import defaultdict
 from math import ceil
 import itertools
+import re
+import boto3
 import numpy as np
+from botocore.handlers import disable_signing
 from maggma.builders import Builder
 from maggma.utils import grouper
 from pymatgen.analysis.magnetism.analyzer import CollinearMagneticStructureAnalyzer
@@ -18,6 +21,8 @@ from emmet.core.settings import EmmetSettings
 from emmet.core.electronic_structure import ElectronicStructureDoc
 from emmet.core.utils import jsanitize
 
+from emmet.builders.utils import query_open_data
+
 SETTINGS = EmmetSettings()
 
 
@@ -43,8 +48,10 @@ class ElectronicStructureBuilder(Builder):
         tasks (Store): Store of task documents
         materials (Store): Store of materials documents
         electronic_structure (Store): Store of electronic structure summary data documents
-        bandstructure_fs (Store): Store of bandstructures
-        dos_fs (Store): Store of DOS
+        bandstructure_fs (Store, str): Store of bandstructures, or S3 URL string with prefix
+            (e.g. s3://materialsproject-parsed/bandstructures).
+        dos_fs (Store, str): Store of DOS, or S3 URL string with bucket and prefix
+            (e.g. s3://materialsproject-parsed/dos).
         chunk_size (int): Chunk size to use for processing. Defaults to 10.
         query (dict): Dictionary to limit materials to be analyzed
         """
@@ -57,8 +64,31 @@ class ElectronicStructureBuilder(Builder):
         self.chunk_size = chunk_size
         self.query = query if query else {}
 
+        self._s3_resource = None
+
+        sources = [tasks, materials]
+
+        fs_stores = [bandstructure_fs, dos_fs]
+
+        for store in fs_stores:
+            if isinstance(store, str):
+                if not re.match("^s3://.*", store):
+                    raise ValueError(
+                        "Please provide an S3 URL "
+                        "in the format s3://{bucket_name}/{prefix}"
+                    )
+
+                if self._s3_resource is None:
+                    self._s3_resource = boto3.resource("s3")
+                    self._s3_resource.meta.client.meta.events.register(
+                        "choose-signer.s3.*", disable_signing
+                    )
+
+            else:
+                sources.append(store)
+
         super().__init__(
-            sources=[tasks, materials, bandstructure_fs, dos_fs],
+            sources=sources,
             targets=[electronic_structure],
             chunk_size=chunk_size,
             **kwargs,
@@ -173,6 +203,7 @@ class ElectronicStructureBuilder(Builder):
             is_gap_direct=mat["other"]["is_gap_direct"],
             is_metal=mat["other"]["is_metal"],
             magnetic_ordering=mat["other"]["magnetic_ordering"],
+            origins=mat["origins"],
             warnings=[],
         )
 
@@ -183,7 +214,6 @@ class ElectronicStructureBuilder(Builder):
             if not np.isclose(
                 mat["other"]["band_gap"], eig_values["bandgap"], atol=0.2, rtol=0.0
             ):
-
                 d["warnings"].append(
                     "Regular parsed band gap and band gap from eigenvalue_band_properties do not agree. "
                     "Using data from eigenvalue_band_properties where appropriate."
@@ -202,7 +232,6 @@ class ElectronicStructureBuilder(Builder):
 
         else:
             try:
-
                 doc = ElectronicStructureDoc.from_bsdos(
                     material_id=mat[self.materials.key],
                     structures=structures,
@@ -210,6 +239,7 @@ class ElectronicStructureBuilder(Builder):
                     is_gap_direct=d["is_gap_direct"],
                     is_metal=d["is_metal"],
                     deprecated=d["deprecated"],
+                    origins=d["origins"],
                     **bs,
                 )
                 doc = self._bsdos_checks(doc, dos[mat["dos"]["task_id"]], structures)
@@ -232,14 +262,13 @@ class ElectronicStructureBuilder(Builder):
             )
 
         if doc.dos is not None:
-            dos_dict = doc.dos.dict()
+            dos_dict = doc.dos.model_dump()
             mag_orderings.update(
                 {dos_dict["total"][Spin.up]["task_id"]: dos_dict["magnetic_ordering"]}
             )
 
         for task_id, ordering in mag_orderings.items():
             if doc.magnetic_ordering != ordering:
-
                 doc.warnings.append(
                     f"Summary data magnetic ordering does not agree with the ordering from {task_id}"
                 )
@@ -261,7 +290,7 @@ class ElectronicStructureBuilder(Builder):
                     f"{bs_entry['task_id']}). A correction calculation is planned."
                 )
 
-        return doc.dict()
+        return doc.model_dump()
 
     def update_targets(self, items):
         """
@@ -310,7 +339,6 @@ class ElectronicStructureBuilder(Builder):
             if not np.allclose(
                 struct.lattice.matrix, struct_prim.lattice.matrix, atol=1e-3
             ):
-
                 if doc.warnings is None:
                     doc.warnings = []
 
@@ -362,10 +390,8 @@ class ElectronicStructureBuilder(Builder):
         other_calcs = []
 
         for task_id in mat["task_types"].keys():
-
             # Handle all line-mode tasks
             if "NSCF Line" in mat["task_types"][task_id]:
-
                 bs_type = None
 
                 task_query = self.tasks.query_one(
@@ -389,6 +415,7 @@ class ElectronicStructureBuilder(Builder):
                     structure = Structure.from_dict(task_query["output"]["structure"])
 
                     kpoints = task_query["orig_inputs"]["kpoints"]
+
                     labels_dict = {
                         label: point
                         for label, point in zip(kpoints["labels"], kpoints["kpoints"])
@@ -401,18 +428,41 @@ class ElectronicStructureBuilder(Builder):
                         bs_type = None
 
                     if bs_type is None:
+                        if isinstance(self.bandstructure_fs, str):
+                            _, _, bucket, prefix = self.bandstructure_fs.strip(
+                                "/"
+                            ).split("/")
 
-                        bs_dict = self.bandstructure_fs.query_one(
-                            {self.bandstructure_fs.key: str(task_id)}
-                        )
+                            bs_dict = query_open_data(
+                                bucket,
+                                prefix,
+                                task_id,
+                                monty_decode=False,
+                                s3_resource=self._s3_resource,
+                            )
+                        else:
+                            bs_dict = self.bandstructure_fs.query_one(
+                                {self.bandstructure_fs.key: str(task_id)}
+                            )
 
                         if bs_dict is not None:
-
                             bs = BandStructureSymmLine.from_dict(bs_dict["data"])
 
-                            bs_type = self._obtain_path_type(
-                                bs.labels_dict, bs.structure
-                            )
+                            labels_dict = {
+                                label: kpoint.frac_coords
+                                for label, kpoint in bs.labels_dict.items()
+                            }
+
+                            try:
+                                bs_type = self._obtain_path_type(
+                                    labels_dict, bs.structure
+                                )
+                            except Exception:
+                                bs_type = None
+
+                        # Clear bs data
+                        bs = None
+                        bs_dict = None
 
                     is_hubbard = task_query["input"]["is_hubbard"]
                     lmaxmix = task_query["input"]["incar"].get(
@@ -431,6 +481,7 @@ class ElectronicStructureBuilder(Builder):
                                 "nkpoints": int(nkpoints),
                                 "updated_on": lu_dt,
                                 "output_structure": structure,
+                                "labels_dict": labels_dict,
                             }
                         )
 
@@ -547,9 +598,10 @@ class ElectronicStructureBuilder(Builder):
     def _obtain_blessed_calculations(
         self, materials_doc, bs_calcs, dos_calcs, other_calcs
     ):
-
         bs_types = ["setyawan_curtarolo", "hinuma", "latimer_munro"]
 
+        materials_doc["origins"] = []
+
         for bs_type in bs_types:
             # select "blessed" bs of each type
             if bs_calcs[bs_type]:
@@ -570,10 +622,19 @@ class ElectronicStructureBuilder(Builder):
                 materials_doc["bandstructure"][bs_type]["lmaxmix"] = sorted_bs_data[0][
                     "lmaxmix"
                 ]
-
-                bs_obj = self.bandstructure_fs.query_one(
-                    criteria={"fs_id": sorted_bs_data[0]["fs_id"]}
-                )
+                if isinstance(self.bandstructure_fs, str):
+                    _, _, bucket, prefix = self.bandstructure_fs.strip("/").split("/")
+                    bs_obj = query_open_data(
+                        bucket,
+                        prefix,
+                        sorted_bs_data[0]["task_id"],
+                        monty_decode=False,
+                        s3_resource=self._s3_resource,
+                    )
+                else:
+                    bs_obj = self.bandstructure_fs.query_one(
+                        criteria={"fs_id": sorted_bs_data[0]["fs_id"]}
+                    )
 
                 materials_doc["bandstructure"][bs_type]["object"] = (
                     bs_obj["data"] if bs_obj is not None else None
@@ -583,8 +644,15 @@ class ElectronicStructureBuilder(Builder):
                     "output_structure"
                 ] = sorted_bs_data[0]["output_structure"]
 
-        if dos_calcs:
+                materials_doc["origins"].append(
+                    {
+                        "name": bs_type,
+                        "task_id": sorted_bs_data[0]["task_id"],
+                        "last_updated": sorted_bs_data[0]["updated_on"],
+                    }
+                )
 
+        if dos_calcs:
             sorted_dos_data = sorted(
                 dos_calcs,
                 key=lambda entry: (
@@ -600,9 +668,20 @@ class ElectronicStructureBuilder(Builder):
 
             materials_doc["dos"]["lmaxmix"] = sorted_dos_data[0]["lmaxmix"]
 
-            dos_obj = self.dos_fs.query_one(
-                criteria={"fs_id": sorted_dos_data[0]["fs_id"]}
-            )
+            if isinstance(self.bandstructure_fs, str):
+                _, _, bucket, prefix = self.dos_fs.strip("/").split("/")
+                dos_obj = query_open_data(
+                    bucket,
+                    prefix,
+                    sorted_dos_data[0]["task_id"],
+                    monty_decode=False,
+                    s3_resource=self._s3_resource,
+                )
+            else:
+                dos_obj = self.dos_fs.query_one(
+                    criteria={"fs_id": sorted_dos_data[0]["fs_id"]}
+                )
+
             materials_doc["dos"]["object"] = (
                 dos_obj["data"] if dos_obj is not None else None
             )
@@ -611,8 +690,15 @@ class ElectronicStructureBuilder(Builder):
                 "output_structure"
             ]
 
-        if other_calcs:
+            materials_doc["origins"].append(
+                {
+                    "name": "dos",
+                    "task_id": sorted_dos_data[0]["task_id"],
+                    "last_updated": sorted_dos_data[0]["updated_on"],
+                }
+            )
 
+        if other_calcs:
             sorted_other_data = sorted(
                 other_calcs,
                 key=lambda entry: (
@@ -631,11 +717,20 @@ class ElectronicStructureBuilder(Builder):
             materials_doc["other"]["magnetic_ordering"] = sorted_other_data[0][
                 "magnetic_ordering"
             ]
+            materials_doc["other"]["last_updated"] = sorted_other_data[0]["updated_on"]
 
             materials_doc["other"]["is_metal"] = (
                 materials_doc["other"]["band_gap"] == 0.0
             )
 
+            materials_doc["origins"].append(
+                {
+                    "name": "electronic_structure",
+                    "task_id": sorted_other_data[0]["task_id"],
+                    "last_updated": sorted_other_data[0]["updated_on"],
+                }
+            )
+
             for prop in [
                 "efermi",
                 "cbm",
@@ -644,7 +739,6 @@ class ElectronicStructureBuilder(Builder):
                 "is_metal",
                 "eigenvalue_band_properties",
             ]:
-
                 # First try other calcs_reversed entries if properties are not found in last
                 if prop not in task_output_data:
                     for calc in sorted_other_data[0]["calcs_reversed"]:
@@ -663,7 +757,6 @@ class ElectronicStructureBuilder(Builder):
         angle_tolerance=SETTINGS.ANGLE_TOL,
         atol=1e-5,
     ):
-
         bs_type = None
 
         if any([label.islower() for label in labels_dict]):
