@@ -15,6 +15,8 @@ class SummaryBuilder(Builder):
         materials,
         thermo,
         xas,
+        chemenv,
+        absorption,
         grain_boundaries,
         electronic_structure,
         magnetism,
@@ -30,15 +32,16 @@ class SummaryBuilder(Builder):
         provenance,
         charge_density_index,
         summary,
-        thermo_type=ThermoType.GGA_GGA_U.value,
+        thermo_type=ThermoType.GGA_GGA_U_R2SCAN.value,
         chunk_size=100,
         query=None,
         **kwargs,
     ):
-
         self.materials = materials
         self.thermo = thermo
         self.xas = xas
+        self.chemenv = chemenv
+        self.absorption = absorption
         self.grain_boundaries = grain_boundaries
         self.electronic_structure = electronic_structure
         self.magnetism = magnetism
@@ -65,6 +68,8 @@ class SummaryBuilder(Builder):
                 materials,
                 thermo,
                 xas,
+                chemenv,
+                absorption,
                 grain_boundaries,
                 electronic_structure,
                 magnetism,
@@ -107,7 +112,6 @@ class SummaryBuilder(Builder):
         self.logger.debug("Processing {} materials.".format(self.total))
 
         for entry in summary_set:
-
             materials_doc = self.materials.query_one({self.materials.key: entry})
 
             valid_static_tasks = set(
@@ -147,7 +151,8 @@ class SummaryBuilder(Builder):
                     {self.piezoelectric.key: entry}
                 ),
                 HasProps.phonon.value: self.phonon.query_one(
-                    {self.phonon.key: {"$in": all_tasks}}, [self.phonon.key],
+                    {self.phonon.key: {"$in": all_tasks}},
+                    [self.phonon.key],
                 ),
                 HasProps.insertion_electrodes.value: list(
                     self.insertion_electrodes.query(
@@ -169,6 +174,12 @@ class SummaryBuilder(Builder):
                 HasProps.eos.value: self.eos.query_one(
                     {self.eos.key: {"$in": all_tasks}}, [self.eos.key]
                 ),
+                HasProps.chemenv.value: self.chemenv.query_one(
+                    {self.chemenv.key: entry}
+                ),
+                HasProps.absorption.value: self.absorption.query_one(
+                    {self.absorption.key: entry}
+                ),
                 HasProps.provenance.value: self.provenance.query_one(
                     {self.provenance.key: entry}
                 ),
@@ -205,7 +216,6 @@ class SummaryBuilder(Builder):
             yield {"query": {self.materials.key: {"$in": list(split)}}}
 
     def process_item(self, item):
-
         material_id = MPID(item[HasProps.materials.value]["material_id"])
         doc = SummaryDoc.from_docs(material_id=material_id, **item)
         return jsanitize(doc.dict(exclude_none=False), allow_bson=True)
