@@ -60,7 +60,6 @@ class PartialChargesBuilder(Builder):
         settings: Optional[EmmetBuildSettings] = None,
         **kwargs,
     ):
-
         self.tasks = tasks
         self.molecules = molecules
         self.charges = charges
@@ -69,7 +68,13 @@ class PartialChargesBuilder(Builder):
         self.settings = EmmetBuildSettings.autoload(settings)
         self.kwargs = kwargs
 
-        super().__init__(sources=[tasks, molecules], targets=[charges])
+        super().__init__(sources=[tasks, molecules], targets=[charges], **kwargs)
+        # Uncomment in case of issue with mrun not connecting automatically to collections
+        # for i in [self.tasks, self.molecules, self.charges]:
+        #     try:
+        #         i.connect()
+        #     except Exception as e:
+        #         print("Could not connect,", e)
 
     def ensure_indexes(self):
         """
@@ -229,15 +234,23 @@ class PartialChargesBuilder(Builder):
                     best_entry = relevant_entries[0]
                     task = best_entry["task_id"]
 
-                    tdoc = self.tasks.query_one({"task_id": task,
-                                                 "formula_alphabetical": formula,
-                                                 "orig": {"$exists": True}})
+                    tdoc = self.tasks.query_one(
+                        {
+                            "task_id": task,
+                            "formula_alphabetical": formula,
+                            "orig": {"$exists": True},
+                        }
+                    )
 
                     if tdoc is None:
                         try:
-                            tdoc = self.tasks.query_one({"task_id": int(task),
-                                                         "formula_alphabetical": formula,
-                                                         "orig": {"$exists": True}})
+                            tdoc = self.tasks.query_one(
+                                {
+                                    "task_id": int(task),
+                                    "formula_alphabetical": formula,
+                                    "orig": {"$exists": True},
+                                }
+                            )
                         except ValueError:
                             tdoc = None
 
@@ -260,7 +273,7 @@ class PartialChargesBuilder(Builder):
 
         self.logger.debug(f"Produced {len(charges_docs)} charges docs for {formula}")
 
-        return jsanitize([doc.dict() for doc in charges_docs], allow_bson=True)
+        return jsanitize([doc.model_dump() for doc in charges_docs], allow_bson=True)
 
     def update_targets(self, items: List[List[Dict]]):
         """
@@ -326,7 +339,6 @@ class PartialSpinsBuilder(Builder):
         settings: Optional[EmmetBuildSettings] = None,
         **kwargs,
     ):
-
         self.tasks = tasks
         self.molecules = molecules
         self.spins = spins
@@ -335,7 +347,13 @@ class PartialSpinsBuilder(Builder):
         self.settings = EmmetBuildSettings.autoload(settings)
         self.kwargs = kwargs
 
-        super().__init__(sources=[tasks, molecules], targets=[spins])
+        super().__init__(sources=[tasks, molecules], targets=[spins], **kwargs)
+        # Uncomment in case of issue with mrun not connecting automatically to collections
+        # for i in [self.tasks, self.molecules, self.spins]:
+        #     try:
+        #         i.connect()
+        #     except Exception as e:
+        #         print("Could not connect,", e)
 
     def ensure_indexes(self):
         """
@@ -354,7 +372,7 @@ class PartialSpinsBuilder(Builder):
         self.molecules.ensure_index("task_ids")
         self.molecules.ensure_index("formula_alphabetical")
 
-        # Search index for charges
+        # Search index for spins
         self.spins.ensure_index("molecule_id")
         self.spins.ensure_index("task_id")
         self.spins.ensure_index("method")
@@ -499,15 +517,23 @@ class PartialSpinsBuilder(Builder):
                     best_entry = relevant_entries[0]
                     task = best_entry["task_id"]
 
-                    tdoc = self.tasks.query_one({"task_id": task,
-                                                 "formula_alphabetical": formula,
-                                                 "orig": {"$exists": True}})
+                    tdoc = self.tasks.query_one(
+                        {
+                            "task_id": task,
+                            "formula_alphabetical": formula,
+                            "orig": {"$exists": True},
+                        }
+                    )
 
                     if tdoc is None:
                         try:
-                            tdoc = self.tasks.query_one({"task_id": int(task),
-                                                         "formula_alphabetical": formula,
-                                                         "orig": {"$exists": True}})
+                            tdoc = self.tasks.query_one(
+                                {
+                                    "task_id": int(task),
+                                    "formula_alphabetical": formula,
+                                    "orig": {"$exists": True},
+                                }
+                            )
                         except ValueError:
                             tdoc = None
 
@@ -529,7 +555,7 @@ class PartialSpinsBuilder(Builder):
             f"Produced {len(spins_docs)} partial spins docs for {formula}"
         )
 
-        return jsanitize([doc.dict() for doc in spins_docs], allow_bson=True)
+        return jsanitize([doc.model_dump() for doc in spins_docs], allow_bson=True)
 
     def update_targets(self, items: List[List[Dict]]):
         """
