@@ -59,7 +59,6 @@ class BondingBuilder(Builder):
         settings: Optional[EmmetBuildSettings] = None,
         **kwargs,
     ):
-
         self.tasks = tasks
         self.molecules = molecules
         self.bonds = bonds
@@ -68,7 +67,13 @@ class BondingBuilder(Builder):
         self.settings = EmmetBuildSettings.autoload(settings)
         self.kwargs = kwargs
 
-        super().__init__(sources=[tasks, molecules], targets=[bonds])
+        super().__init__(sources=[tasks, molecules], targets=[bonds], **kwargs)
+        # Uncomment in case of issue with mrun not connecting automatically to collections
+        # for i in [self.tasks, self.molecules, self.bonds]:
+        #     try:
+        #         i.connect()
+        #     except Exception as e:
+        #         print("Could not connect,", e)
 
     def ensure_indexes(self):
         """
@@ -87,7 +92,7 @@ class BondingBuilder(Builder):
         self.molecules.ensure_index("task_ids")
         self.molecules.ensure_index("formula_alphabetical")
 
-        # Search index for charges
+        # Search index for bonds
         self.bonds.ensure_index("molecule_id")
         self.bonds.ensure_index("method")
         self.bonds.ensure_index("task_id")
@@ -247,15 +252,23 @@ class BondingBuilder(Builder):
                     best_entry = relevant_entries[0]
                     task = best_entry["task_id"]
 
-                    tdoc = self.tasks.query_one({"task_id": task,
-                                                 "formula_alphabetical": formula,
-                                                 "orig": {"$exists": True}})
+                    tdoc = self.tasks.query_one(
+                        {
+                            "task_id": task,
+                            "formula_alphabetical": formula,
+                            "orig": {"$exists": True},
+                        }
+                    )
 
                     if tdoc is None:
                         try:
-                            tdoc = self.tasks.query_one({"task_id": int(task),
-                                                         "formula_alphabetical": formula,
-                                                         "orig": {"$exists": True}})
+                            tdoc = self.tasks.query_one(
+                                {
+                                    "task_id": int(task),
+                                    "formula_alphabetical": formula,
+                                    "orig": {"$exists": True},
+                                }
+                            )
                         except ValueError:
                             tdoc = None
 
@@ -277,7 +290,7 @@ class BondingBuilder(Builder):
 
         self.logger.debug(f"Produced {len(bonding_docs)} bonding docs for {formula}")
 
-        return jsanitize([doc.dict() for doc in bonding_docs], allow_bson=True)
+        return jsanitize([doc.model_dump() for doc in bonding_docs], allow_bson=True)
 
     def update_targets(self, items: List[List[Dict]]):
         """
