@@ -36,6 +36,7 @@ class SummaryBuilder(Builder):
         charges: Store,
         spins: Store,
         bonds: Store,
+        metal_binding: Store,
         orbitals: Store,
         redox: Store,
         thermo: Store,
@@ -45,11 +46,11 @@ class SummaryBuilder(Builder):
         settings: Optional[EmmetBuildSettings] = None,
         **kwargs,
     ):
-
         self.molecules = molecules
         self.charges = charges
         self.spins = spins
         self.bonds = bonds
+        self.metal_binding = metal_binding
         self.orbitals = orbitals
         self.redox = redox
         self.thermo = thermo
@@ -60,9 +61,37 @@ class SummaryBuilder(Builder):
         self.kwargs = kwargs
 
         super().__init__(
-            sources=[molecules, charges, spins, bonds, orbitals, redox, thermo, vibes],
+            sources=[
+                molecules,
+                charges,
+                spins,
+                bonds,
+                metal_binding,
+                orbitals,
+                redox,
+                thermo,
+                vibes,
+            ],
             targets=[summary],
+            **kwargs,
         )
+        # Uncomment in case of issue with mrun not connecting automatically to collections
+        # for i in [
+        #     self.molecules,
+        #     self.charges,
+        #     self.spins,
+        #     self.bonds,
+        #     self.metal_binding,
+        #     self.orbitals,
+        #     self.redox,
+        #     self.thermo,
+        #     self.vibes,
+        #     self.summary
+        # ]:
+        #     try:
+        #         i.connect()
+        #     except Exception as e:
+        #         print("Could not connect,", e)
 
     def ensure_indexes(self):
         """
@@ -105,6 +134,15 @@ class SummaryBuilder(Builder):
         self.bonds.ensure_index("last_updated")
         self.bonds.ensure_index("formula_alphabetical")
 
+        # Search index for metal_binding
+        self.metal_binding.ensure_index("molecule_id")
+        self.metal_binding.ensure_index("solvent")
+        self.metal_binding.ensure_index("lot_solvent")
+        self.metal_binding.ensure_index("property_id")
+        self.metal_binding.ensure_index("last_updated")
+        self.metal_binding.ensure_index("formula_alphabetical")
+        self.metal_binding.ensure_index("method")
+
         # Search index for orbitals
         self.orbitals.ensure_index("molecule_id")
         self.orbitals.ensure_index("task_id")
@@ -268,13 +306,30 @@ class SummaryBuilder(Builder):
 
             d = {
                 "molecules": mol,
-                "partial_charges": _group_docs(list(self.charges.query({"molecule_id": mol_id})), True),
-                "partial_spins": _group_docs(list(self.spins.query({"molecule_id": mol_id})), True),
-                "bonding": _group_docs(list(self.bonds.query({"molecule_id": mol_id})), True),
-                "orbitals": _group_docs(list(self.orbitals.query({"molecule_id": mol_id})), False),
-                "redox": _group_docs(list(self.redox.query({"molecule_id": mol_id})), False),
-                "thermo": _group_docs(list(self.thermo.query({"molecule_id": mol_id})), False),
-                "vibration": _group_docs(list(self.vibes.query({"molecule_id": mol_id})), False),
+                "partial_charges": _group_docs(
+                    list(self.charges.query({"molecule_id": mol_id})), True
+                ),
+                "partial_spins": _group_docs(
+                    list(self.spins.query({"molecule_id": mol_id})), True
+                ),
+                "bonding": _group_docs(
+                    list(self.bonds.query({"molecule_id": mol_id})), True
+                ),
+                "metal_binding": _group_docs(
+                    list(self.metal_binding.query({"molecule_id": mol_id})), True
+                ),
+                "orbitals": _group_docs(
+                    list(self.orbitals.query({"molecule_id": mol_id})), False
+                ),
+                "redox": _group_docs(
+                    list(self.redox.query({"molecule_id": mol_id})), False
+                ),
+                "thermo": _group_docs(
+                    list(self.thermo.query({"molecule_id": mol_id})), False
+                ),
+                "vibration": _group_docs(
+                    list(self.vibes.query({"molecule_id": mol_id})), False
+                ),
             }
 
             to_delete = list()
@@ -295,7 +350,7 @@ class SummaryBuilder(Builder):
 
         self.logger.debug(f"Produced {len(summary_docs)} summary docs for {formula}")
 
-        return jsanitize([doc.dict() for doc in summary_docs], allow_bson=True)
+        return jsanitize([doc.model_dump() for doc in summary_docs], allow_bson=True)
 
     def update_targets(self, items: List[List[Dict]]):
         """
