@@ -24,53 +24,53 @@ __author__ = "Evan Spotte-Smith"
 SETTINGS = EmmetBuildSettings()
 
 single_mol_thermo = {
-    "Zn": {"enthalpy": 1.481, "entropy": 38.384},
-    "Xe": {"enthalpy": 1.481, "entropy": 40.543},
-    "Tl": {"enthalpy": 1.481, "entropy": 41.857},
-    "Ti": {"enthalpy": 1.481, "entropy": 37.524},
-    "Te": {"enthalpy": 1.481, "entropy": 40.498},
-    "Sr": {"enthalpy": 1.481, "entropy": 39.334},
-    "Sn": {"enthalpy": 1.481, "entropy": 40.229},
-    "Si": {"enthalpy": 1.481, "entropy": 35.921},
-    "Sb": {"enthalpy": 1.481, "entropy": 40.284},
-    "Se": {"enthalpy": 1.481, "entropy": 39.05},
-    "S": {"enthalpy": 1.481, "entropy": 36.319},
-    "Rn": {"enthalpy": 1.481, "entropy": 42.095},
-    "Pt": {"enthalpy": 1.481, "entropy": 41.708},
-    "Rb": {"enthalpy": 1.481, "entropy": 39.23},
-    "Po": {"enthalpy": 1.481, "entropy": 41.915},
-    "Pb": {"enthalpy": 1.481, "entropy": 41.901},
-    "P": {"enthalpy": 1.481, "entropy": 36.224},
-    "O": {"enthalpy": 1.481, "entropy": 34.254},
-    "Ne": {"enthalpy": 1.481, "entropy": 34.919},
-    "N": {"enthalpy": 1.481, "entropy": 33.858},
-    "Na": {"enthalpy": 1.481, "entropy": 35.336},
-    "Mg": {"enthalpy": 1.481, "entropy": 35.462},
-    "Li": {"enthalpy": 1.481, "entropy": 31.798},
-    "Kr": {"enthalpy": 1.481, "entropy": 39.191},
-    "K": {"enthalpy": 1.481, "entropy": 36.908},
-    "In": {"enthalpy": 1.481, "entropy": 40.132},
-    "I": {"enthalpy": 1.481, "entropy": 40.428},
-    "H": {"enthalpy": 1.481, "entropy": 26.014},
-    "He": {"enthalpy": 1.481, "entropy": 30.125},
-    "Ge": {"enthalpy": 1.481, "entropy": 38.817},
-    "Ga": {"enthalpy": 1.481, "entropy": 38.609},
-    "F": {"enthalpy": 1.481, "entropy": 34.767},
-    "Cu": {"enthalpy": 1.481, "entropy": 38.337},
-    "Cl": {"enthalpy": 1.481, "entropy": 36.586},
-    "Ca": {"enthalpy": 1.481, "entropy": 36.984},
-    "C": {"enthalpy": 1.481, "entropy": 33.398},
-    "Br": {"enthalpy": 1.481, "entropy": 39.012},
-    "Bi": {"enthalpy": 1.481, "entropy": 41.915},
-    "Be": {"enthalpy": 1.481, "entropy": 32.544},
-    "Ba": {"enthalpy": 1.481, "entropy": 40.676},
-    "B": {"enthalpy": 1.481, "entropy": 33.141},
-    "Au": {"enthalpy": 1.481, "entropy": 41.738},
-    "At": {"enthalpy": 1.481, "entropy": 41.929},
-    "As": {"enthalpy": 1.481, "entropy": 38.857},
-    "Ar": {"enthalpy": 1.481, "entropy": 36.983},
-    "Al": {"enthalpy": 1.481, "entropy": 35.813},
-    "Ag": {"enthalpy": 1.481, "entropy": 39.917},
+    "Zn1": {"enthalpy": 1.481, "entropy": 38.384},
+    "Xe1": {"enthalpy": 1.481, "entropy": 40.543},
+    "Tl1": {"enthalpy": 1.481, "entropy": 41.857},
+    "Ti1": {"enthalpy": 1.481, "entropy": 37.524},
+    "Te1": {"enthalpy": 1.481, "entropy": 40.498},
+    "Sr1": {"enthalpy": 1.481, "entropy": 39.334},
+    "Sn1": {"enthalpy": 1.481, "entropy": 40.229},
+    "Si1": {"enthalpy": 1.481, "entropy": 35.921},
+    "Sb1": {"enthalpy": 1.481, "entropy": 40.284},
+    "Se1": {"enthalpy": 1.481, "entropy": 39.05},
+    "S1": {"enthalpy": 1.481, "entropy": 36.319},
+    "Rn1": {"enthalpy": 1.481, "entropy": 42.095},
+    "Pt1": {"enthalpy": 1.481, "entropy": 41.708},
+    "Rb1": {"enthalpy": 1.481, "entropy": 39.23},
+    "Po1": {"enthalpy": 1.481, "entropy": 41.915},
+    "Pb1": {"enthalpy": 1.481, "entropy": 41.901},
+    "P1": {"enthalpy": 1.481, "entropy": 36.224},
+    "O1": {"enthalpy": 1.481, "entropy": 34.254},
+    "Ne1": {"enthalpy": 1.481, "entropy": 34.919},
+    "N1": {"enthalpy": 1.481, "entropy": 33.858},
+    "Na1": {"enthalpy": 1.481, "entropy": 35.336},
+    "Mg1": {"enthalpy": 1.481, "entropy": 35.462},
+    "Li1": {"enthalpy": 1.481, "entropy": 31.798},
+    "Kr1": {"enthalpy": 1.481, "entropy": 39.191},
+    "K1": {"enthalpy": 1.481, "entropy": 36.908},
+    "In1": {"enthalpy": 1.481, "entropy": 40.132},
+    "I1": {"enthalpy": 1.481, "entropy": 40.428},
+    "H1": {"enthalpy": 1.481, "entropy": 26.014},
+    "He1": {"enthalpy": 1.481, "entropy": 30.125},
+    "Ge1": {"enthalpy": 1.481, "entropy": 38.817},
+    "Ga1": {"enthalpy": 1.481, "entropy": 38.609},
+    "F1": {"enthalpy": 1.481, "entropy": 34.767},
+    "Cu1": {"enthalpy": 1.481, "entropy": 38.337},
+    "Cl1": {"enthalpy": 1.481, "entropy": 36.586},
+    "Ca1": {"enthalpy": 1.481, "entropy": 36.984},
+    "C1": {"enthalpy": 1.481, "entropy": 33.398},
+    "Br1": {"enthalpy": 1.481, "entropy": 39.012},
+    "Bi1": {"enthalpy": 1.481, "entropy": 41.915},
+    "Be1": {"enthalpy": 1.481, "entropy": 32.544},
+    "Ba1": {"enthalpy": 1.481, "entropy": 40.676},
+    "B1": {"enthalpy": 1.481, "entropy": 33.141},
+    "Au1": {"enthalpy": 1.481, "entropy": 41.738},
+    "At1": {"enthalpy": 1.481, "entropy": 41.929},
+    "As1": {"enthalpy": 1.481, "entropy": 38.857},
+    "Ar1": {"enthalpy": 1.481, "entropy": 36.983},
+    "Al1": {"enthalpy": 1.481, "entropy": 35.813},
+    "Ag1": {"enthalpy": 1.481, "entropy": 39.917},
 }
 
 
@@ -123,7 +123,6 @@ class ThermoBuilder(Builder):
         settings: Optional[EmmetBuildSettings] = None,
         **kwargs,
     ):
-
         self.tasks = tasks
         self.molecules = molecules
         self.thermo = thermo
@@ -131,7 +130,13 @@ class ThermoBuilder(Builder):
         self.settings = EmmetBuildSettings.autoload(settings)
         self.kwargs = kwargs
 
-        super().__init__(sources=[tasks, molecules], targets=[thermo])
+        super().__init__(sources=[tasks, molecules], targets=[thermo], **kwargs)
+        # Uncomment in case of issue with mrun not connecting automatically to collections
+        # for i in [self.tasks, self.molecules, self.thermo]:
+        #     try:
+        #         i.connect()
+        #     except Exception as e:
+        #         print("Could not connect,", e)
 
     def ensure_indexes(self):
         """
@@ -166,11 +171,19 @@ class ThermoBuilder(Builder):
         temp_query["deprecated"] = False
 
         self.logger.info("Finding documents to process")
-        all_mols = list(self.molecules.query(temp_query, [self.molecules.key, "formula_alphabetical"]))
+        all_mols = list(
+            self.molecules.query(
+                temp_query, [self.molecules.key, "formula_alphabetical"]
+            )
+        )
 
         processed_docs = set([e for e in self.thermo.distinct("molecule_id")])
         to_process_docs = {d[self.molecules.key] for d in all_mols} - processed_docs
-        to_process_forms = {d["formula_alphabetical"] for d in all_mols if d[self.molecules.key] in to_process_docs}
+        to_process_forms = {
+            d["formula_alphabetical"]
+            for d in all_mols
+            if d[self.molecules.key] in to_process_docs
+        }
 
         N = ceil(len(to_process_forms) / number_splits)
 
@@ -199,11 +212,19 @@ class ThermoBuilder(Builder):
         temp_query["deprecated"] = False
 
         self.logger.info("Finding documents to process")
-        all_mols = list(self.molecules.query(temp_query, [self.molecules.key, "formula_alphabetical"]))
+        all_mols = list(
+            self.molecules.query(
+                temp_query, [self.molecules.key, "formula_alphabetical"]
+            )
+        )
 
         processed_docs = set([e for e in self.thermo.distinct("molecule_id")])
         to_process_docs = {d[self.molecules.key] for d in all_mols} - processed_docs
-        to_process_forms = {d["formula_alphabetical"] for d in all_mols if d[self.molecules.key] in to_process_docs}
+        to_process_forms = {
+            d["formula_alphabetical"]
+            for d in all_mols
+            if d[self.molecules.key] in to_process_docs
+        }
 
         self.logger.info(f"Found {len(to_process_docs)} unprocessed documents")
         self.logger.info(f"Found {len(to_process_forms)} unprocessed formulas")
@@ -229,7 +250,9 @@ class ThermoBuilder(Builder):
             [dict] : a list of new thermo docs
         """
 
-        def _add_single_atom_enthalpy_entropy(task: TaskDocument, doc: MoleculeThermoDoc):
+        def _add_single_atom_enthalpy_entropy(
+            task: TaskDocument, doc: MoleculeThermoDoc
+        ):
             initial_mol = task.output.initial_molecule
             # If single atom, try to add enthalpy and entropy
             if len(initial_mol) == 1:
@@ -245,6 +268,7 @@ class ThermoBuilder(Builder):
                             doc.electronic_energy,
                             vals["enthalpy"],
                             vals["entropy"],
+                            convert_energy=False,
                         )
             return doc
 
@@ -307,15 +331,23 @@ class ThermoBuilder(Builder):
                 )[0]
                 task = best["task_id"]
 
-                tdoc = self.tasks.query_one({"task_id": task,
-                                             "formula_alphabetical": formula,
-                                             "orig": {"$exists": True}})
+                tdoc = self.tasks.query_one(
+                    {
+                        "task_id": task,
+                        "formula_alphabetical": formula,
+                        "orig": {"$exists": True},
+                    }
+                )
 
                 if tdoc is None:
                     try:
-                        tdoc = self.tasks.query_one({"task_id": int(task),
-                                                     "formula_alphabetical": formula,
-                                                     "orig": {"$exists": True}})
+                        tdoc = self.tasks.query_one(
+                            {
+                                "task_id": int(task),
+                                "formula_alphabetical": formula,
+                                "orig": {"$exists": True},
+                            }
+                        )
                     except ValueError:
                         tdoc = None
 
@@ -350,9 +382,10 @@ class ThermoBuilder(Builder):
                     for entry in thermo_entries:
                         mol1 = Molecule.from_dict(entry["molecule"])
                         mol2 = Molecule.from_dict(best_spec["molecule"])
-                        if ((mm.fit(mol1, mol2) or mol1 == mol2)
-                            and (sum(evaluate_lot(best_spec["level_of_theory"])) <
-                                 sum(evaluate_lot(entry["level_of_theory"])))):
+                        if (mm.fit(mol1, mol2) or mol1 == mol2) and (
+                            sum(evaluate_lot(best_spec["level_of_theory"]))
+                            < sum(evaluate_lot(entry["level_of_theory"]))
+                        ):
                             matching_structures.append(entry)
 
                     if len(matching_structures) == 0:
@@ -390,9 +423,11 @@ class ThermoBuilder(Builder):
                         task_doc_dict,
                         correction_task=task_doc_spec,
                         molecule_id=mol.molecule_id,
-                        deprecated=False
+                        deprecated=False,
+                    )
+                    thermo_doc = _add_single_atom_enthalpy_entropy(
+                        task_doc_dict, thermo_doc
                     )
-                    thermo_doc = _add_single_atom_enthalpy_entropy(task_doc_dict, thermo_doc)
                     this_thermo_docs.append(thermo_doc)
                     break
 
@@ -408,18 +443,31 @@ class ThermoBuilder(Builder):
                 with_eval_e = list()
                 for member in collection:
                     if member.correction_level_of_theory is None:
-                        with_eval_e.append((member, sum(evaluate_lot(member.level_of_theory)),
-                                            member.electronic_energy))
+                        with_eval_e.append(
+                            (
+                                member,
+                                sum(evaluate_lot(member.level_of_theory)),
+                                member.electronic_energy,
+                            )
+                        )
                     else:
                         dict_lot = sum(evaluate_lot(member.level_of_theory))
                         spec_lot = sum(evaluate_lot(member.correction_level_of_theory))
-                        with_eval_e.append((member, (dict_lot + spec_lot) / 2, member.electronic_energy))
+                        with_eval_e.append(
+                            (
+                                member,
+                                (dict_lot + spec_lot) / 2,
+                                member.electronic_energy,
+                            )
+                        )
 
-                thermo_docs.append(sorted(with_eval_e, key=lambda x: (x[1], x[2]))[0][0])
+                thermo_docs.append(
+                    sorted(with_eval_e, key=lambda x: (x[1], x[2]))[0][0]
+                )
 
         self.logger.debug(f"Produced {len(thermo_docs)} thermo docs for {formula}")
 
-        return jsanitize([doc.dict() for doc in thermo_docs], allow_bson=True)
+        return jsanitize([doc.model_dump() for doc in thermo_docs], allow_bson=True)
 
     def update_targets(self, items: List[List[Dict]]):
         """
