@@ -39,7 +39,6 @@ class TaskValidator(MapBuilder):
         # Set up potcar cache if appropriate
         if self.settings.VASP_VALIDATE_POTCAR_HASHES:
             if not self.potcar_hashes:
-
                 from pymatgen.io.vasp.inputs import PotcarSingle
 
                 hashes = defaultdict(dict)  # type: dict
@@ -53,7 +52,7 @@ class TaskValidator(MapBuilder):
                         potcar = PotcarSingle.from_symbol_and_functional(
                             symbol=potcar_symbol, functional=functional
                         )
-                        hashes[calc_type][potcar_symbol] = potcar.get_potcar_hash()
+                        hashes[calc_type][potcar_symbol] = potcar.md5_header_hash
 
                 self.potcar_hashes = potcar_hashes
         else:
