@@ -10,7 +10,7 @@ __author__ = "Evan Spotte-Smith <ewcspottesmith@lbl.gov>"
 
 @pytest.fixture(scope="session")
 def tasks_store(test_dir):
-    return JSONStore(test_dir / "C3H4Li1O3.json.gz")
+    return JSONStore(test_dir / "C2H4.json.gz")
 
 
 @pytest.fixture(scope="session")
@@ -35,5 +35,5 @@ def test_orbital_builder(tasks_store, mol_store, orbital_store):
     builder = OrbitalBuilder(tasks_store, mol_store, orbital_store)
     builder.run()
 
-    assert orbital_store.count() == 27
-    assert orbital_store.count({"open_shell": True}) == 14
+    assert orbital_store.count() == 20
+    assert orbital_store.count({"open_shell": True}) == 9
